@@ -1,7 +1,7 @@
 from .libs import *
 class obj:
     def __init__(self):
-        pass
+        self.color = (255, 255, 255)
     def render(self, x, y):
         pass
     def abs_(self, i, j):
@@ -13,7 +13,7 @@ def render(obj_, width, heigth):
         for j in range(heigth):
             r = obj_.render(i - width / 2, j - heigth / 2)
             if r < 1:
-                p[len(p)-1].append((255, 255, 255))
+                p[len(p)-1].append(obj_.color)
             else:
                 p[len(p)-1].append((0, 0, 0))
     return np.array(p)
\ No newline at end of file
